{
    "$graph": [
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "TransDecoder.LongOrfs"
            ],
            "inputs": [
                {
                    "format": "http://edamontology.org/format_3475",
                    "id": "#TransDecoder.LongOrfs-v5.cwl/geneToTranscriptMap",
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--gene_trans_map"
                    },
                    "label": "gene-to-transcript mapping",
                    "doc": "gene-to-transcript identifier mapping file (tab-delimited, gene_id<tab>trans_id<return>)"
                },
                {
                    "id": "#TransDecoder.LongOrfs-v5.cwl/geneticCode",
                    "type": [
                        "null",
                        "#TransDecoder-v5-genetic_codes.yaml/genetic_codes"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-G"
                    },
                    "label": "genetic code",
                    "doc": "genetic code (default: universal; see PerlDoc; options: Euplotes, Tetrahymena, Candida, Acetabularia)"
                },
                {
                    "id": "#TransDecoder.LongOrfs-v5.cwl/minimumProteinLength",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-m"
                    },
                    "label": "minimum protein length",
                    "doc": "minimum protein length (default: 100)"
                },
                {
                    "id": "#TransDecoder.LongOrfs-v5.cwl/strandSpecific",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-S"
                    },
                    "label": "strand-specific",
                    "doc": "strand-specific (only analyzes top strand)"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#TransDecoder.LongOrfs-v5.cwl/transcriptsFile",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-t"
                    },
                    "label": "transcripts.fasta",
                    "doc": "FASTA formatted sequence file containing your transcripts."
                }
            ],
            "doc": "TransDecoder identifies candidate coding regions within transcript sequences, such as those generated by de novo RNA-Seq transcript assembly using Trinity, or constructed based on RNA-Seq alignments to the genome using Tophat and Cufflinks.\nTransDecoder identifies likely coding sequences based on the following criteria:\n      + a minimum length open reading frame (ORF) is found in a transcript sequence\n      + a log-likelihood score similar to what is computed by the GeneID software is > 0.\n      + the above coding score is greatest when the ORF is scored in the 1st reading frame\n      as compared to scores in the other 2 forward reading frames.\n      + if a candidate ORF is found fully encapsulated by the coordinates of another candidate ORF,\n      the longer one is reported. However, a single transcript can report multiple ORFs\n      (allowing for operons, chimeras, etc).\n      + a PSSM is built/trained/used to refine the start codon prediction.\n      + optional the putative peptide has a match to a Pfam domain above the noise cutoff score.\n\nPlease visit https://github.com/TransDecoder/TransDecoder/wiki for full documentation.\n\nReleases can be downloaded from https://github.com/TransDecoder/TransDecoder/releases",
            "label": "TransDecoder.LongOrfs: Perl script, which extracts the long open reading frames",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "type": "enum",
                            "name": "#TransDecoder-v5-genetic_codes.yaml/genetic_codes",
                            "symbols": [
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/universal",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Euplotes",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Tetrahymena",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Candida",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Acetabularia",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Canonical",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Vertebrates",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Arthropods",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Echinoderms",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Molluscs",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Ascidians",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Nematodes",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Platyhelminths",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Yeasts",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Euascomycetes",
                                "#TransDecoder-v5-genetic_codes.yaml/genetic_codes/Mitochondrial-Protozoans"
                            ]
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1024
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "greatfireball/ime_transdecoder:5.0.2"
                }
            ],
            "id": "#TransDecoder.LongOrfs-v5.cwl",
            "http://schema.org/author": "Maxim Scheremetjew",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "outputs": [
                {
                    "id": "#TransDecoder.LongOrfs-v5.cwl/workingDir",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.transcriptsFile.basename).transdecoder_dir"
                    }
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "baseCommand": [
                "TransDecoder.Predict"
            ],
            "inputs": [
                {
                    "id": "#TransDecoder.Predict-v5.cwl/geneticCode",
                    "type": [
                        "null",
                        "#TransDecoder-v5-genetic_codes.yaml/genetic_codes"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-G"
                    },
                    "label": "genetic code",
                    "doc": "genetic code (default: universal; see PerlDoc; options: Euplotes, Tetrahymena, Candida, Acetabularia)"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/longOpenReadingFrames",
                    "type": "Directory"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/noRefineStarts",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--no_refine_starts"
                    },
                    "label": "No refine starts",
                    "doc": "Start refinement identifies potential start codons for 5' partial ORFs using a PWM, process on by default."
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/retainBlastpHits",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--retain_blastp_hits"
                    },
                    "label": "Retain Blastp hits",
                    "doc": "blastp output in '-outfmt 6' format.\nAny ORF with a blast match will be retained in the final output.\n"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/retainLongOrfsLength",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--retain_long_orfs_length"
                    },
                    "label": "Retain long ORFs length",
                    "doc": "Under 'strict' mode, retain all ORFs found that are equal or longer than these many nucleotides\neven if no other evidence marks it as coding (default: 1000000) so essentially turned off by default.\n"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/retainLongOrfsMode",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--retain_long_orfs_mode"
                    },
                    "label": "Retain long ORFs mode",
                    "doc": "'dynamic' (default) or 'strict'. In dynamic mode, sets range according to 1%FDR in random sequence of same GC content."
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/retainPfamHits",
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--retain_pfam_hits"
                    },
                    "label": "Retain Pfam hits",
                    "doc": "Domain table output file from running hmmscan to search Pfam (see transdecoder.github.io for info).\nAny ORF with a pfam domain hit will be retained in the final output.\n"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/singleBestOnly",
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "--single_best_only"
                    },
                    "label": "Single best only",
                    "doc": "Retain only the single best ORF per transcript (prioritized by homology then ORF length)"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/train",
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-T"
                    },
                    "label": "minimum protein length",
                    "doc": "If no --train, top longest ORFs to train Markov Model (hexamer stats) (default: 500)\nNote, 10x this value are first selected for removing redundancies,\nand then this -T value of longest ORFs are selected from the non-redundant set.\n"
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#TransDecoder.Predict-v5.cwl/transcriptsFile",
                    "type": "File",
                    "inputBinding": {
                        "position": 0,
                        "prefix": "-t"
                    },
                    "label": "transcripts.fasta",
                    "doc": "FASTA formatted sequence file containing your transcripts."
                }
            ],
            "outputs": [
                {
                    "id": "#TransDecoder.Predict-v5.cwl/bed_output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.transcriptsFile.basename).transdecoder.bed"
                    },
                    "format": "http://edamontology.org/format_3003"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/coding_regions",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.transcriptsFile.basename).transdecoder.cds"
                    },
                    "format": "http://edamontology.org/format_1929"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/gff3_output",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.transcriptsFile.basename).transdecoder.gff3"
                    },
                    "format": "http://edamontology.org/format_1975"
                },
                {
                    "id": "#TransDecoder.Predict-v5.cwl/peptide_sequences",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.transcriptsFile.basename).transdecoder.pep"
                    },
                    "format": "http://edamontology.org/format_1929"
                }
            ],
            "doc": "TransDecoder identifies candidate coding regions within transcript sequences, such as those generated by de novo RNA-Seq transcript assembly using Trinity, or constructed based on RNA-Seq alignments to the genome using Tophat and Cufflinks.\nTransDecoder identifies likely coding sequences based on the following criteria:\n      + a minimum length open reading frame (ORF) is found in a transcript sequence\n      + a log-likelihood score similar to what is computed by the GeneID software is > 0.\n      + the above coding score is greatest when the ORF is scored in the 1st reading frame\n      as compared to scores in the other 2 forward reading frames.\n      + if a candidate ORF is found fully encapsulated by the coordinates of another candidate ORF,\n      the longer one is reported. However, a single transcript can report multiple ORFs \n      (allowing for operons, chimeras, etc).\n      + a PSSM is built/trained/used to refine the start codon prediction.\n      + optional the putative peptide has a match to a Pfam domain above the noise cutoff score.\n      \nPlease visit https://github.com/TransDecoder/TransDecoder/wiki for full documentation.\nReleases can be downloaded from https://github.com/TransDecoder/TransDecoder/releases\n",
            "label": "TransDecoder.Predict: Perl script, which predicts the likely coding regions",
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#TransDecoder-v5-genetic_codes.yaml/genetic_codes"
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 1024
                },
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        "$(inputs.transcriptsFile)",
                        {
                            "entryname": "$(inputs.transcriptsFile.basename).transdecoder_dir",
                            "entry": "$(inputs.longOpenReadingFrames)",
                            "writable": true
                        }
                    ]
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "greatfireball/ime_transdecoder:5.0.2"
                }
            ],
            "id": "#TransDecoder.Predict-v5.cwl",
            "http://schema.org/author": "Maxim Scheremetjew",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0"
        },
        {
            "class": "Workflow",
            "label": "TransDecoder 2 step workflow, running TransDecoder.LongOrfs (step 1) followed by TransDecoder.Predict (step2)",
            "inputs": [
                {
                    "id": "#main/singleBestOnly",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "format": "http://edamontology.org/format_1929",
                    "id": "#main/transcriptsFile",
                    "type": "File"
                },
                {
                    "format": "http://edamontology.org/format_3475",
                    "id": "#main/geneToTranscriptMap",
                    "type": [
                        "null",
                        "File"
                    ]
                },
                {
                    "id": "#main/geneticCode",
                    "type": [
                        "null",
                        "#TransDecoder-v5-genetic_codes.yaml/genetic_codes"
                    ]
                },
                {
                    "id": "#main/minimumProteinLength",
                    "type": [
                        "null",
                        "int"
                    ]
                },
                {
                    "id": "#main/strandSpecific",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#main/noRefineStarts",
                    "type": [
                        "null",
                        "boolean"
                    ]
                },
                {
                    "id": "#main/retainBlastpHits",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/retainLongOrfsLength",
                    "type": [
                        "null",
                        "int"
                    ]
                },
                {
                    "id": "#main/retainLongOrfsMode",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/retainPfamHits",
                    "type": [
                        "null",
                        "string"
                    ]
                },
                {
                    "id": "#main/train",
                    "type": [
                        "null",
                        "int"
                    ]
                }
            ],
            "outputs": [
                {
                    "id": "#main/bed_output",
                    "outputSource": [
                        "#main/predict_coding_regions/bed_output"
                    ],
                    "type": "File"
                },
                {
                    "id": "#main/coding_regions",
                    "outputSource": [
                        "#main/predict_coding_regions/coding_regions"
                    ],
                    "type": "File"
                },
                {
                    "id": "#main/gff3_output",
                    "outputSource": [
                        "#main/predict_coding_regions/gff3_output"
                    ],
                    "type": "File"
                },
                {
                    "id": "#main/peptide_sequences",
                    "outputSource": [
                        "#main/predict_coding_regions/peptide_sequences"
                    ],
                    "type": "File"
                }
            ],
            "steps": [
                {
                    "id": "#main/extract_long_orfs",
                    "in": [
                        {
                            "id": "#main/extract_long_orfs/transcriptsFile",
                            "source": "#main/transcriptsFile"
                        },
                        {
                            "id": "#main/extract_long_orfs/geneToTranscriptMap",
                            "source": "#main/geneToTranscriptMap"
                        },
                        {
                            "id": "#main/extract_long_orfs/geneticCode",
                            "source": "#main/geneticCode"
                        },
                        {
                            "id": "#main/extract_long_orfs/minimumProteinLength",
                            "source": "#main/minimumProteinLength"
                        },
                        {
                            "id": "#main/extract_long_orfs/strandSpecific",
                            "source": "#main/strandSpecific"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/extract_long_orfs/workingDir"
                        }
                    ],
                    "run": "#TransDecoder.LongOrfs-v5.cwl",
                    "label": "Extracts the long open reading frames"
                },
                {
                    "id": "#main/predict_coding_regions",
                    "in": [
                        {
                            "id": "#main/predict_coding_regions/longOpenReadingFrames",
                            "source": "#main/extract_long_orfs/workingDir"
                        },
                        {
                            "id": "#main/predict_coding_regions/singleBestOnly",
                            "source": "#main/singleBestOnly"
                        },
                        {
                            "id": "#main/predict_coding_regions/noRefineStarts",
                            "source": "#main/noRefineStarts"
                        },
                        {
                            "id": "#main/predict_coding_regions/retainBlastpHits",
                            "source": "#main/retainBlastpHits"
                        },
                        {
                            "id": "#main/predict_coding_regions/retainLongOrfsLength",
                            "source": "#main/retainLongOrfsLength"
                        },
                        {
                            "id": "#main/predict_coding_regions/retainLongOrfsMode",
                            "source": "#main/retainLongOrfsMode"
                        },
                        {
                            "id": "#main/predict_coding_regions/retainPfamHits",
                            "source": "#main/retainPfamHits"
                        },
                        {
                            "id": "#main/predict_coding_regions/train",
                            "source": "#main/train"
                        },
                        {
                            "id": "#main/predict_coding_regions/transcriptsFile",
                            "source": "#main/transcriptsFile"
                        }
                    ],
                    "out": [
                        {
                            "id": "#main/predict_coding_regions/bed_output"
                        },
                        {
                            "id": "#main/predict_coding_regions/coding_regions"
                        },
                        {
                            "id": "#main/predict_coding_regions/gff3_output"
                        },
                        {
                            "id": "#main/predict_coding_regions/peptide_sequences"
                        }
                    ],
                    "run": "#TransDecoder.Predict-v5.cwl",
                    "label": "Predicts the likely coding regions"
                }
            ],
            "requirements": [
                {
                    "class": "SchemaDefRequirement",
                    "types": [
                        {
                            "$import": "#TransDecoder-v5-genetic_codes.yaml/genetic_codes"
                        }
                    ]
                }
            ],
            "id": "#main",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute, 2018",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/author": "Maxim Scheremetjew"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/docs/schema_org_rdfa.html",
        "http://edamontology.org/EDAM_1.20.owl",
        "http://edamontology.org/EDAM_1.16.owl"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
